@@ -25,6 +25,8 @@
 // Main function
 int main(int argc, char *argv[])
 {
+  // Fixes blurry icons with fractional scaling
+  QGuiApplication::setAttribute(Qt::AA_UseHighDpiPixmaps);
   QApplication app(argc, argv);
 
   KLocalizedString::setApplicationDomain("ktuberling");
